@@ -1,4 +1,5 @@
 import contextlib
+import sys
 from os import PathLike
 from socket import socket
 from types import TracebackType
@@ -18,7 +19,8 @@ from testcontainers.core.exceptions import ContainerConnectException, ContainerS
 from testcontainers.core.labels import LABEL_SESSION_ID, SESSION_ID
 from testcontainers.core.network import Network
 from testcontainers.core.utils import is_arm, setup_logger
-from testcontainers.core.waiting_utils import wait_container_is_ready, wait_for_logs
+from testcontainers.core.wait_strategies import LogMessageWaitStrategy
+from testcontainers.core.waiting_utils import WaitStrategy, wait_container_is_ready
 
 if TYPE_CHECKING:
     from docker.models.containers import Container
@@ -69,6 +71,7 @@ class DockerContainer:
         volumes: Optional[list[tuple[str, str, str]]] = None,
         network: Optional[Network] = None,
         network_aliases: Optional[list[str]] = None,
+        _wait_strategy: Optional[WaitStrategy] = None,
         **kwargs: Any,
     ) -> None:
         self.env = env or {}
@@ -96,6 +99,7 @@ class DockerContainer:
             self.with_network_aliases(*network_aliases)
 
         self._kwargs = kwargs
+        self._wait_strategy: Optional[WaitStrategy] = _wait_strategy
 
     def with_env(self, key: str, value: str) -> Self:
         self.env[key] = value
@@ -165,6 +169,11 @@ class DockerContainer:
             return self.with_kwargs(platform="linux/amd64")
         return self
 
+    def waiting_for(self, strategy: WaitStrategy) -> "DockerContainer":
+        """Set a wait strategy to be used after container start."""
+        self._wait_strategy = strategy
+        return self
+
     def start(self) -> Self:
         if not c.ryuk_disabled and self.image != c.ryuk_image:
             logger.debug("Creating Ryuk container")
@@ -195,6 +204,9 @@ class DockerContainer:
             **{**network_kwargs, **self._kwargs},
         )
 
+        if self._wait_strategy is not None:
+            self._wait_strategy.wait_until_ready(self)
+
         logger.info("Container started: %s", self._container.short_id)
         return self
 
@@ -204,7 +216,11 @@ class DockerContainer:
         self.get_docker_client().client.close()
 
     def __enter__(self) -> Self:
-        return self.start()
+        try:
+            return self.start()
+        except:  # noqa: E722, RUF100
+            self.__exit__(*sys.exc_info())
+            raise
 
     def __exit__(
         self, exc_type: Optional[type[BaseException]], exc_val: Optional[BaseException], exc_tb: Optional[TracebackType]
@@ -215,15 +231,17 @@ class DockerContainer:
         connection_mode: ConnectionMode
         connection_mode = self.get_docker_client().get_connection_mode()
 
-        # mypy:
-        container = self._container
-        assert container is not None
-
         if connection_mode == ConnectionMode.docker_host:
             return self.get_docker_client().host()
         elif connection_mode == ConnectionMode.gateway_ip:
+            # mypy:
+            container = self._container
+            assert container is not None
             return self.get_docker_client().gateway_ip(container.id)
         elif connection_mode == ConnectionMode.bridge_ip:
+            # mypy:
+            container = self._container
+            assert container is not None
             return self.get_docker_client().bridge_ip(container.id)
         else:
             # ensure that we covered all possible connection_modes
@@ -264,6 +282,18 @@ class DockerContainer:
             raise ContainerStartException("Container should be started before getting logs")
         return self._container.logs(stderr=False), self._container.logs(stdout=False)
 
+    def reload(self) -> None:
+        """Reload container information for compatibility with wait strategies."""
+        if self._container:
+            self._container.reload()
+
+    @property
+    def status(self) -> str:
+        """Get container status for compatibility with wait strategies."""
+        if not self._container:
+            return "not_started"
+        return cast("str", self._container.status)
+
     def exec(self, command: Union[str, list[str]]) -> ExecResult:
         if not self._container:
             raise ContainerStartException("Container should be started before executing a command")
@@ -319,7 +349,7 @@ class Reaper:
         )
         rc = Reaper._container
         assert rc is not None
-        wait_for_logs(rc, r".* Started!", timeout=20, raise_on_exit=True)
+        rc.waiting_for(LogMessageWaitStrategy(r".* Started!").with_startup_timeout(20))
 
         container_host = rc.get_container_host_ip()
         container_port = int(rc.get_exposed_port(8080))
