@@ -13,10 +13,10 @@ WIN = "win"
 
 def setup_logger(name: str) -> logging.Logger:
     logger = logging.getLogger(name)
-    logger.setLevel(logging.INFO)
-    handler = logging.StreamHandler()
-    handler.setLevel(logging.INFO)
-    logger.addHandler(handler)
+    # logger.setLevel(logging.INFO)
+    # handler = logging.StreamHandler()
+    # handler.setLevel(logging.INFO)
+    # logger.addHandler(handler)
     return logger
 
 
