@@ -10,7 +10,7 @@ from testcontainers.core.waiting_utils import wait_container_is_ready
 class RabbitMqContainer(DockerContainer):
     """
     Test container for RabbitMQ. The example below spins up a RabbitMQ broker and uses the
-    `pika client library <(https://pypi.org/project/pika/)>`__ to establish a connection to the
+    `pika client library <https://pypi.org/project/pika/>`__ to establish a connection to the
     broker.
 
     Example:
